@@ -1,5 +1,5 @@
 from ._constants import *
 from ._package import Package
 from ._exceptions import TwineCheckFailed, FailedToInstallPackage, \
-    CannotInitializeEnvironment, CodeExecutionFailed
+    CannotInitializeEnvironment, CodeExecutionFailed, PytypedNotFound
 
